@@ -11,6 +11,7 @@ import datetime
 import logging
 import re
 import sys
+import time
 from decimal import Decimal
 from io import BytesIO
 from ssl import CERT_NONE, CERT_OPTIONAL, CERT_REQUIRED
@@ -421,39 +422,6 @@ class Error(Exception):
     pass
 
 
-<<<<<<< Updated upstream
-# if __name__ == '__main__':
-#     e6x_connection = connect(host="e6data-cls6-rj7u4l-042347692bba1a38.elb.us-east-1.amazonaws.com",
-#                          port=9000,
-#                          scheme="e6xdb",
-#                          username="admin",
-#                          database="dev_hive_100gb",
-#                          auth=None,
-#                          configuration=None,
-#                          kerberos_service_name=None,
-#                          password="admin",
-#                          check_hostname=None,
-#                          ssl_cert=None,
-#                          thrift_transport=None)
-#     cursor = e6x_connection.cursor()
-#     query = 'SELECT * FROM date_dim limit 4;'
-#     cursor.execute(query)
-#     all_records = cursor.fetchall()
-#     print(all_records)
-#     # cursor.close()
-#     e6x_connection.close()
-#
-#     e6x_connection.reopen()
-#
-#     cursor = e6x_connection.cursor()
-#     query = 'SELECT * FROM date_dim limit 4;'
-#     cursor.execute(query)
-#     all_records = cursor.fetchall()
-#     print(all_records)
-#     # cursor.close()
-#
-#     e6x_connection.close()
-=======
 if __name__ == '__main__':
     connection = connect(host="localhost",
                          port=9000,
@@ -509,7 +477,6 @@ if __name__ == '__main__':
     bdata = []
     for i in range(1000):
         bdata += cursor.fetchmany()
->>>>>>> Stashed changes
 
 #
 # Type Objects and Constructors
